==> camel-salesforce-2.15-20150307.024122-156-sources.jar: org/apache/camel/component/salesforce/api/dto/FilteredLookupInfo.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.salesforce.api.dto;

public class FilteredLookupInfo extends AbstractDTOBase {

    private String controllingFields;
    private Boolean dependent;
    private Boolean optionalFilter;

    public String getControllingFields() {
        return controllingFields;
    }

    public void setControllingFields(String controllingFields) {
        this.controllingFields = controllingFields;
    }

    public Boolean getDependent() {
        return dependent;
    }

    public void setDependent(Boolean dependent) {
        this.dependent = dependent;
    }

    public Boolean getOptionalFilter() {
        return optionalFilter;
    }

    public void setOptionalFilter(Boolean optionalFilter) {
        this.optionalFilter = optionalFilter;
    }
}

==> camel-salesforce-2.17-20151107.033401-28-sources.jar: org/apache/camel/component/salesforce/api/dto/FilteredLookupInfo.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.salesforce.api.dto;

import java.util.List;

public class FilteredLookupInfo extends AbstractDTOBase {

    private List<String> controllingFields;
    private Boolean dependent;
    private Boolean optionalFilter;

    public List<String> getControllingFields() {
        return controllingFields;
    }

    public void setControllingFields(List<String> controllingFields) {
        this.controllingFields = controllingFields;
    }

    public Boolean getDependent() {
        return dependent;
    }

    public void setDependent(Boolean dependent) {
        this.dependent = dependent;
    }

    public Boolean getOptionalFilter() {
        return optionalFilter;
    }

    public void setOptionalFilter(Boolean optionalFilter) {
        this.optionalFilter = optionalFilter;
    }
}
